package com.diagbot.client.hystrix;

import com.diagbot.client.TranServiceClient;
import com.diagbot.client.bean.HosCodeVO;
import com.diagbot.dto.GetDiseaseIcdDTO;
import com.diagbot.dto.GetTopPatientInfoDTO;
import com.diagbot.dto.HospitalDeptInfoDTO;
import com.diagbot.dto.IndexDataDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.SysSetInfoDTO;
import com.diagbot.vo.GetDiseaseIcdVO;
import com.diagbot.vo.GetTopPatientInfoVO;
import com.diagbot.vo.HospitalDeptInfoVO;
import com.diagbot.vo.HospitalSetVO;
import com.diagbot.vo.IndexDataSaveVO;
import com.diagbot.vo.IndexDataiIds;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.RequestBody;

import javax.validation.Valid;
import java.util.List;
import java.util.Map;

/**
 * @Description: 调用信息对接层服务
 * @author: gaodm
 * @time: 2019/2/1 17:00
 */
@Component
@Slf4j
public class TranServiceHystrix implements TranServiceClient {
    @Override
    public RespDTO<HospitalDeptInfoDTO> getHospitalDeptInfo(HospitalDeptInfoVO hospitalDeptInfoVO) {
        log.error("【hystrix】调用{}异常", "getHospitalDeptInfo");
        return null;
    }

    @Override
    public RespDTO<List<GetDiseaseIcdDTO>> getDiseaseIcds(GetDiseaseIcdVO getDiseaseIcdVO) {
        log.error("【hystrix】调用{}异常", "getDiseaseIcds");
        return null;
    }

    @Override
    public RespDTO<GetTopPatientInfoDTO> getTopPatientInfo(GetTopPatientInfoVO getTopPatientInfoVO) {
        log.error("【hystrix】调用{}异常", "getTopPatientInfo");
        return null;
    }

    /**
     * 根据医院编码获取化验公表映射关系-itemName不为空
     *
     * @param hosCodeVO
     * @return
     */
    @Override
    public RespDTO<Map<String, Map<String, String>>> getLisConfigByHosCode_NotEmptyItemName(@RequestBody HosCodeVO hosCodeVO) {
        log.error("【hystrix】调用{}异常", "getLisConfigByHosCode_NotEmptyItemName");
        return null;
    }

    /**
     * 根据医院编码获取化验公表映射关系-itemName为空
     *
     * @param hosCodeVO
     * @return
     */
    @Override
    public RespDTO<Map<String, String>> getLisConfigByHosCode_EmptyItemName(@RequestBody HosCodeVO hosCodeVO) {
        log.error("【hystrix】调用{}异常", "getLisConfigByHosCode_EmptyItemName");
        return null;
    }

    /**
     * 根据医院编码获取辅检公表映射关系
     *
     * @param hosCodeVO
     * @return
     */
    @Override
    public RespDTO<Map<String, String>> getPacsConfigByHosCode(@RequestBody HosCodeVO hosCodeVO) {
        log.error("【hystrix】调用{}异常", "getPacsConfigByHosCode");
        return null;
    }

    /**
     * 根据医院编码获取提示信息标题映射关系
     *
     * @param hosCodeVO
     * @return
     */
    @Override
    public RespDTO<Map<String, String>> getTitleMappingHosCode(@RequestBody HosCodeVO hosCodeVO) {
        log.error("【hystrix】调用{}异常", "getTitleMappingHosCode");
        return null;
    }

    /**
     * 根据医院编码查询诊断icd映射
     *
     * @param hosCodeVO
     * @return
     */
    @Override
    public RespDTO<Map<String, String>> getDiseaseIcdByHosCode(@RequestBody HosCodeVO hosCodeVO) {
        log.error("【hystrix】调用{}异常", "getDiseaseIcdByHosCode");
        return null;
    }

    /**
     * 数据服务模式是否对外对接
     *
     * @param hosCodeVO
     * @return
     */
    @Override
    public RespDTO<Boolean> isConnect(HosCodeVO hosCodeVO) {
        log.error("【hystrix】调用{}异常", "isConnect");
        return null;
    }

    /**
     * 根据医院编码获取化验公表映射关系，公表项做key
     *
     * @param hosCodeVO
     * @return
     */
    @Override
    public RespDTO<Map<String, List<String>>> getLisConfigByUniqueNameAndHosCode(@RequestBody HosCodeVO hosCodeVO) {
        log.error("【hystrix】调用{}异常", "getLisConfigByUniqueNameAndHosCode");
        return null;
    }

    /**
     * 根据医院编码查询辅检公表映射，公表项做key
     *
     * @param hosCodeVO
     * @return
     */
    @Override
    public RespDTO<Map<String, List<String>>> getPacsConfigByUniqueNameAndHosCode(@RequestBody HosCodeVO hosCodeVO) {
        log.error("【hystrix】调用{}异常", "getPacsConfigByUniqueNameAndHosCode");
        return null;
    }

    @Override
    public RespDTO<List<IndexDataDTO>> getIndexDatas(@Valid IndexDataiIds indexDataFindVO) {
        log.error("【hystrix】调用{}异常", "getIndexDatas");
        return null;
    }

    @Override
    public RespDTO<Boolean> saveIndexDatas(@Valid IndexDataSaveVO indexDataSaveVO) {
        log.error("【hystrix】调用{}异常", "saveIndexDatas");
        return null;
    }

    @Override
    public RespDTO<List<SysSetInfoDTO>> getSysSetInfoDatas(@Valid HospitalSetVO hospitalSetVO) {
        log.error("【hystrix】调用{}异常", "getSysSetInfoDatas");
        return null;
    }
}